import os, platform
import ctypes
from ctypes import *

# Load the correct DLL file, note the use of CDLL on 64-bit and WinDLL on 32-bit
if platform.machine().endswith('64'):
   bardecodeLibrary = os.getcwd() + '/../DLL/SoftekBarcode64DLL.dll'
   a=CDLL(bardecodeLibrary)
else:
   bardecodeLibrary = os.getcwd() + '/../DLL/SoftekBarcodeDLL.dll'
   a=WinDLL(bardecodeLibrary)

# Set the name of the image to decode
inputFile = 'file.tif'

# Create an instance of the bardecode toolkit
a.mtCreateBarcodeInstance.restype = ctypes.c_void_p
hBarcode = c_void_p(a.mtCreateBarcodeInstance())

# Set a license key
a.mtSetLicenseKey(hBarcode, 'YOUR LICENSE KEY'.encode("utf-8")) 

# Set the ReadQRCode property
a.mtSetReadQRCode(hBarcode, True)

# Scan the input file for barcodes
nBarcodes = a.mtScanBarCode(hBarcode, inputFile.encode("utf-8"))
# Or load the file into a byte array
# data = open(inputFile, "rb").read()
# nBarcodes = a.mtScanBarCodeFromString(c_void_p(hBarcode), data, data.__sizeof__())

# Collect the output
for x in range(1, nBarcodes + 1):
   a.mtGetBarString.restype = ctypes.c_char_p
   barcodeValue = a.mtGetBarString(hBarcode, x)
   a.mtGetBarStringType.restype = ctypes.c_char_p
   barcodeType = a.mtGetBarStringType(hBarcode, x)   
   print ("Barcode", x)
   print ("Value = ", barcodeValue.decode("utf-8"))
   print ("Type = ", barcodeType.decode("utf-8"))
   print ("Quality score = ", a.mtGetBarStringQualityScore(hBarcode,x))
   nDirection = a.mtGetBarStringDirection(hBarcode, x)
   if nDirection == 1:
      print ("Direction = Left to Right")
   elif nDirection == 2:
      print ("Direction = Top to Bottom")
   elif nDirection == 4:
      print ("Direction = Right to Left")
   elif nDirection == 8:
      print ("Direction = Bottom to Top")
   tlx = a.mtGetBarStringTlx(hBarcode, x)
   tly = a.mtGetBarStringTly(hBarcode, x)
   brx = a.mtGetBarStringBrx(hBarcode, x)
   bry = a.mtGetBarStringBry(hBarcode, x)
   print ("Top Left = ", tlx, ",", tly);
   print ("Bottom Right = ", brx, ",", bry)
   print ("\n")


a.mtDestroyBarcodeInstance(hBarcode)

r = input('Press return to exit\n')
